Attribute VB_Name = "Utils"
Option Explicit

Public Sub LogCheck(fname As String, maxSize As Currency, numBackups As Integer)

    'Receives: File name, Maximum size, Number of backups
    'Returns: Nothing
    'Program to manage log files. When they get above max size, copies original log to backup,
    'keeps numBackups of backup files, deletes original log file.
    'Note - had to use currency for max size, because Long only goes to 2 Gig.
    
    If fExist(fname) Then
        If fSize(fname) > maxSize Then
            'Get base name for log file - without extension.
            Dim baseName As String
            baseName = Left(fname, Rat(".", fname))

            Dim i As Integer
            Dim srcExt As String
            Dim destExt As String
            For i = numBackups To 2 Step -1
                srcExt = PadL(Trim(CStr(i - 1)), 3, "0")
                destExt = PadL(Trim(CStr(i)), 3, "0")
                fCopy baseName & srcExt, baseName & destExt
            Next i
            fCopy fname, baseName & "001"
            fErase fname
        End If
    End If

End Sub

Public Function GetDateFromDailyFileName(ByVal fileName As String) As Date
    
    'Receives: Filename for the daily file
    'Returns: Date from the daily file filename.
    'Takes the name of the daily file and converts it to a date.
    
    Dim dateString As String
    Dim month As String
    Dim monthNum As String
    
    'Remove path from file name.
    fileName = SubStr(fileName, Rat("\", fileName) + 1, 8)
    
    'Translate from month name to numbers.
    month = Upper(SubStr(fileName, 1, 3))
    Select Case month
        Case "JAN"
            monthNum = "01"
        Case "FEB"
            monthNum = "02"
        Case "MAR"
            monthNum = "03"
        Case "APR"
            monthNum = "04"
        Case "MAY"
            monthNum = "05"
        Case "JUN"
            monthNum = "06"
        Case "JUL"
            monthNum = "07"
        Case "AUG"
            monthNum = "08"
        Case "SEP"
            monthNum = "09"
        Case "OCT"
            monthNum = "10"
        Case "NOV"
            monthNum = "11"
        Case "DEC"
            monthNum = "12"
        Case Else
            MsgBox "Bad Month: " & month, , "Error - GetChepDate"
            monthNum = "00"
    End Select
            
    'Put together string containing date - YYYY/MM/DD.
    If monthNum <> "00" Then
        dateString = "20" & SubStr(fileName, 7, 2) & "/" & monthNum & "/" & SubStr(fileName, 4, 2)
    Else
        dateString = ""
    End If
    
    GetDateFromDailyFileName = CtoD(dateString)

End Function

Public Sub DeleteFileIndex(fileName As String)

    'Receives: Name of database file.
    'Returns: Nothing.
    'Attempt to erase index file for given dbf file.  On all passes except for the
    'last one, retry erasing the file.  On the last attempt, display an error message.
    
    Dim i As Integer
    Dim fileToErase As String
    fileToErase = SubStr(fileName, 1, Rat(".", fileName)) & "idx"
    For i = 0 To 2
        If Not fErase(fileToErase) Then
            If i = 2 Then
                MsgBox "Unable to delete file " & fileToErase & ".", vbCritical, "Error - DeleteFileIndex"
            End If
        Else
            Exit For
        End If
    Next i
    
End Sub

Public Sub DisplayAddress()

  'Receives: Nothing.
  'Returns: Nothing.
  'Function to display the current shipto address on clippership's right screen.
  
  Dim myXVars As KiDataView
  Set myXVars = CS32.XVars
  myXVars.Retrieve
    
  'Clear the right screen.
  CS32.RightMiddle ""
  
  'Send address fields to right screen.
  Dim i As Integer
  Dim myField As String
  For i = 1 To 7
    myField = "SHIPTO" & Str(i, 1, 0)
    If Len(RTrim(myXVars(myField))) > 0 Then
      CS32.RightMiddle myXVars(myField)
    End If
  Next i
  CS32.RightMiddle myXVars("ZIP")
  CS32.RightMiddle myXVars("COUNTRY")
  CS32.RightMiddle myXVars("PHONE")
  CS32.RightMiddle " "
  
End Sub

Public Sub ShowDV(myDv As KiDataView)

  'Receives: KiDataView to display.
  'Returns: Nothing.
  'Testing function, displays a dialog, containing the kidataview.
  
  DlgCreate "your DV", 20, 80
  DlgGrid 1, 1, LinkTo(XC1), 70, 18, myDv
  DlgButton 19, 70, "&Ok"
  DlgDraw
    
End Sub

Public Function GetDetailRecords(dailyFile As String, masterTrack As String) As KiDataView

    'Receives: Name of daily file, master tracking number to retrieve children for.
    'Returns: KiDataView of all records in detail file which match given master tracking number.
    'Return all records from detail file that match given master tracking number.

    'Calculate name of detail file.
    'First, take path off of file name.
    Dim fileName As String
    Dim lastDirPos As Integer
    lastDirPos = InStrRev(dailyFile, "\")
    If lastDirPos = 0 Then
        fileName = dailyFile
    Else
        fileName = SubStr(dailyFile, lastDirPos + 1)
    End If
    'Next, convert to corresponding detail file name.
    Dim detlName As String
    If fileName = "cs_ship.fil" Then
        detlName = "cs_det.fil"
    Else
        detlName = Left(dailyFile, Len(dailyFile) - 2) & "det"
    End If
    
    'Look the master tracking number up in the detail file.
    Dim detailDV As KiDataView
    Set detailDV = DbfSelect(detlName, "shipmentID = '" & masterTrack & "' .and. status <> 'VOID'")

    Set GetDetailRecords = detailDV
    
End Function

Public Sub PopulateNetWgts(wgtlist As String)

    'Receives: List containing the weight and the dimensions
    'Returns: Nothing
    'populate weights and dims and send to .Net
    
    Dim myvars As KiDataView
    Set myvars = CS32.XVars
    
    Dim msg As String
    Dim rtnstr As String
        
    myvars.Retrieve
    msg = "POP" & msgdel & PopVars(myvars)
    rtnstr = SendNet(msg)
    
    msg = "SETWGTS" & msgdel & wgtlist
    rtnstr = SendNet(msg)
    
    rtnstr = SendNet("AFTERLASTFIELD" & msgdel)
    If Len(Trim(rtnstr)) > 0 Then
        RetrvVars rtnstr, myvars
    End If
       
End Sub

Public Function PopulateWgtList(weight As Double, length As Double, width As Double, height As Double) As String

    Dim wgtlist As String
        
    wgtlist = wgtlist & CStr(weight) & msgdel
    wgtlist = wgtlist & CStr(length) & msgdel
    wgtlist = wgtlist & CStr(width) & msgdel
    wgtlist = wgtlist & CStr(height) & msgdel
    
    PopulateWgtList = wgtlist

End Function

